@@ -102,10 +102,8 @@ sub send_reply {
     $raw ||= "";
     my $id = $self->id;
     my $bj = $conn->bound_jid;
-    my $from_jid = $self->to;
-    my $to = $bj ? (" to='" . $bj->as_string_exml . "'") : "";
-    my $from = $from_jid ? (" from='" . $from_jid . "'") : "";
-    my $xml = qq{<iq$to$from type='$type' id='$id'>$raw</iq>};
+    my $to = $bj ? ("to='" . $bj->as_string_exml . "'") : "";
+    my $xml = qq{<iq $to type='$type' id='$id'>$raw</iq>};
     $conn->xmllog->info($xml);
     $conn->write(\$xml);
 }
@@ -504,17 +502,9 @@ sub process_iq_setauth {
 
 
     my $accept = sub {
-        my $cb = shift;
-        my $authjid = shift;
-
-        # create default JID
-        unless (defined $authjid) {
-            my $sname = $vhost->name;
-            $authjid = "$username\@$sname";
-        }
-
         # register
-        my $jid = DJabberd::JID->new("$authjid/$resource");
+        my $sname = $vhost->name;
+        my $jid = DJabberd::JID->new("$username\@$sname/$resource");
 
         unless ($jid) {
             $reject->();
